convert_to_list: Prepare questions as a list for dynamic generation of form

View source: R/utils.R

convert_to_listR Documentation

Prepare questions as a list for dynamic generation of form

Description

Prepare questions as a list for dynamic generation of form

Usage

convert_to_list(questions_tb)

Arguments

questions_tb

a tibble of questions. Needs id and question columns

Value

list_form a list for the form


Hoohm/PVQtools documentation built on March 17, 2022, 5:14 p.m.